==> XMLObject-0.0.3.tar.gz: XMLObject-0.0.3/tests/xbelTest.py <==
# Copyright (C) 2004 Philippe Normand <phil@respyre.org>
#
# This file is part of XMLObject (http://xmlobject.base-art.net)
#
# Under PSF License (see COPYING)

import sys
sys.path.append('..')

from XMLObject import *

class title(XMLObject):
    content = TextNode()

class desc(title): pass
class info(title): pass

class separator(XMLObject):
    pass

class icon(XMLObject):
    pass

class alias(XMLObject):
    ref = IntegerAttribute()
    

class bookmark(XMLObject):
    href = StringAttribute()
    added = IntegerAttribute(facultative=True)
    visited = IntegerAttribute(facultative=True)
    title = ItemNode('title')

class folder(XMLObject):
    id = StringAttribute()
    added = IntegerAttribute(facultative=True)
    folded = StringAttribute(default='yes')
    toolbar = StringAttribute(default='no',facultative=True)
    title = ItemNode('title', facultative=True)
    info = ItemNode('info', facultative=True)
    desc = ItemNode('desc', facultative=True)
    icon = ItemNode('icon', facultative=True)
    bookmarks = ListNode('bookmark')
    
    
class xbel(XMLObject):
    title = ItemNode('title')
    desc = ItemNode('desc')
    folders = ListNode('folder')
    bookmarks = ListNode('bookmark')

f = open('/home/phil/bookmarks.xml')
lines = f.read()
f.close()
xb = xbel()
xb.fromXml(lines)
##xb.title = title(content='Test')

st =  xb.toXml()
#print >>sys.stdout, st
f = open('toto.xml','w')
f.write(st)
f.close()
st2 = xbel()
st2.fromXml(st)

if st2.toXml() == st:
    print 'okYeah'
else:
    from difflib import unified_diff
    print >>sys.stdout, ''.join(unified_diff(st2.toXml().splitlines(1),st.splitlines(1),'new','old'))
    f = open('st.xml','w')
    f.write(st)
    f.close()
    f = open('st2.xml','w')
    f.write(st2.toXml())
    f.close()
    
d = desc()
d.content = 'foo'
#print d.toXml()

test = bookmark()
test.title = title(content='FooBar')
test.href= "http://foo.com"

#print test.toXml()
f = folder()
f.bookmarks.append(test)
f.title = title(content = 'FooFolder')

#print f.toXml()

==> XMLObject-0.1.2.tar.gz: XMLObject-0.1.2/tests/xbelTest.py <==
# Copyright (C) 2004 Philippe Normand <phil@respyre.org>
#
# This file is part of XMLObject (http://xmlobject.base-art.net)
#
# Under PSF License (see COPYING)

import sys
sys.path.append('..')

from XMLObject import *

class title(XMLObject):
    content = TextNode()

class desc(title): pass
class info(title): pass

class separator(XMLObject):
    pass

class icon(XMLObject):
    pass

class alias(XMLObject):
    ref = IntegerAttribute()
    

class bookmark(XMLObject):
    href = StringAttribute()
    added = IntegerAttribute(optional=True)
    visited = IntegerAttribute(optional=True)
    title = ItemNode('title')

class folder(XMLObject):
    id = StringAttribute()
    added = IntegerAttribute(optional=True)
    folded = StringAttribute(default='yes')
    toolbar = StringAttribute(default='no',optional=True)
    title = ItemNode('title', optional=True)
    info = ItemNode('info', optional=True)
    desc = ItemNode('desc', optional=True)
    icon = ItemNode('icon', optional=True)
    bookmarks = ListNode('bookmark')
    
    
class xbel(XMLObject):
    title = ItemNode('title')
    desc = ItemNode('desc')
    folders = ListNode('folder')
    bookmarks = ListNode('bookmark')

f = open('/home/phil/bookmarks.xml')
lines = f.read()
f.close()
xb = xbel.fromXml(lines)
##xb.title = title(content='Test')

st =  xb.toXml()
#print >>sys.stdout, st
f = open('toto.xml','w')
f.write(st)
f.close()
st2 = xbel.fromXml(st)

if st2.toXml() == st:
    print 'okYeah'
else:
    from difflib import unified_diff
    print >>sys.stdout, ''.join(unified_diff(st2.toXml().splitlines(1),st.splitlines(1),'new','old'))
    f = open('st.xml','w')
    f.write(st)
    f.close()
    f = open('st2.xml','w')
    f.write(st2.toXml())
    f.close()
    
d = desc()
d.content = 'foo'
#print d.toXml()

test = bookmark()
test.title = title(content='FooBar')
test.href= "http://foo.com"

#print test.toXml()
f = folder()
f.bookmarks.append(test)
f.title = title(content = 'FooFolder')

#print f.toXml()
